/**
 * The message handler IDs.
 * @type {string}
 */
// LINT.IfChange
const SEND_FEEDBACK_NAME = 'sendFeedback';
const PROMOTED_PRODUCT_LINK_NAME = 'promotedProductLink';
const HELP_ACTION_NAME = 'helpAction';
const SEARCHBOX_NAME = 'searchBox';
const SUPPORT_URL_NAME = 'supportURL';
// LINT.ThenChange(../GHKMainWebViewController.m:message_handler_names)

/**
 * The message keys.
 * @type {string}
 */
// LINT.IfChange
const PROMOTED_PRODUCT_LINK_RESULT_ID = 'promotedProductLinkResultID';
const HELP_ACTION_RESULT_JSON = 'helpActionResultJSON';
const SUPPORT_URL = 'supportURL';
// LINT.ThenChange(../GHKMainWebViewController.m:message_keys)

/**
 * Defines the callback function for the Help Panel object, which posts a
 * message to be read by HelpKit's main WebView.
 * @param {!Page} page The page that contains the Help Panel object.
 */
window.in_app = function(page) {
  const helpPanelObj = page.getChild();
  // TODO (kimmoses): Determine typeof and update check for explicit type.
  if (helpPanelObj == undefined) {
    return;
  }
  helpPanelObj.setSendFeedbackCallback(function() {
    window.webkit.messageHandlers[SEND_FEEDBACK_NAME].postMessage({});
  });
  helpPanelObj.setPromotedProductLinkCallback(function(
      promotedProductLinkResultId) {
    window.webkit.messageHandlers[PROMOTED_PRODUCT_LINK_NAME].postMessage({
      [PROMOTED_PRODUCT_LINK_RESULT_ID]: promotedProductLinkResultId,
    });
  });
  helpPanelObj.setHelpActionCallback(function(helpAction) {
    window.webkit.messageHandlers[HELP_ACTION_NAME].postMessage({
      [HELP_ACTION_RESULT_JSON]: helpAction.result,
    });
  });
  helpPanelObj.setSearchBoxCallback(function() {
    window.webkit.messageHandlers[SEARCHBOX_NAME].postMessage({});
  });
  helpPanelObj.setSupportUrlCallback(function(supportUrl) {
    window.webkit.messageHandlers[SUPPORT_URL_NAME].postMessage({
      [SUPPORT_URL]: supportUrl,
    });
  });
};
